#
# spec file for package python3-click
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-click
Version:        6.6
Release:        1.2
Summary:        A simple wrapper around optparse for powerful command line utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://github.com/mitsuhiko/click
Source:         https://files.pythonhosted.org/packages/source/c/click/click-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Click is a Python package for creating beautiful command line interfaces
in a composable way with as little code as necessary.  It's the "Command
Line Interface Creation Kit".  It's highly configurable but comes with
sensible defaults out of the box.

It aims to make the process of writing command line tools quick and fun
while also preventing any frustration caused by the inability to implement
an intended CLI API.

%prep
%setup -q -n click-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README
%{python3_sitelib}/*

%changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Apr  9 2016 arun@gmx.de
- update to version 6.6:
  * Fix bug in `click.Path` where it would crash when passed a
    `-`. See #551.
* Sat Mar 26 2016 arun@gmx.de
- update to version 6.4:
  * Fix bug in bash completion where click would discard one or more
    trailing arguments. See #471.
* Wed Feb 24 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 6.3:
  * Fix argument checks for interpreter invoke with `-m` and `-c` on
    Windows.
  * Fixed a bug that cased locale detection to error out on Python 3.
* Fri Nov 27 2015 arun@gmx.de
- update to version 6.2:
  * Correct fix for hidden progress bars.
* Fri Nov 27 2015 arun@gmx.de
- update to version 6.1:
  * Resolved an issue with invisible progress bars no longer
    rendering.
  * Disable chain commands with subcommands as they were inherently
    broken.
  * Fix `MissingParameter` not working without parameters passed.
* Wed Nov 25 2015 arun@gmx.de
- update to version 6.0:
  * Optimized the progressbar rendering to not render when it did not
    actually change.
  * Explicitly disallow nargs=-1 with a set default.
  * The context is now closed before it's popped from the stack.
  * Added support for short aliases for the false flag on toggles.
  * Click will now attempt to aid you with debugging locale errors
    better by listing with the help of the OS what locales are
    available.
  * Click used to return byte strings on Python 2 in some unit-testing
    situations.  This has been fixed to correctly return unicode
    strings now.
  * For Windows users on Python 2, Click will now handle Unicode more
    correctly handle Unicode coming in from the system.  This also has
    the disappointing side effect that filenames will now be always
    unicode by default in the `Path` type which means that this can
    introduce small bugs for code not aware of this.
  * Added a `type` parameter to `Path` to force a specific string type
    on the value.
  * For users running Python on Windows the `echo`) and `prompt`
    functions now work with full unicode functionality in the Python
    windows console by emulating an output stream.  This also applies
    to getting the virtual output and input streams via
    `click.get_text_stream(...)`.
  * Unittests now always force a certain virtual terminal width.
  * Added support for allowing dashes to indicate standard streams to
    the `Path` type.
  * Multi commands in chain mode no longer propagate arguments left
    over from parsing to the callbacks.  It's also now disallowed
    through an exception when optional arguments are attached to multi
    commands if chain mode is enabled.
  * Relaxed restriction that disallowed chained commands to have other
    chained commands as child commands.
  * Arguments with positive nargs can now have defaults
    implemented. Previously this configuration would often result in
    slightly unexpected values be returned.
* Wed Oct  7 2015 arun@gmx.de
- update to version 5.1:
  * Fix a bug in `pass_obj` that would accidentally pass the context
    too.
- changes from version 5.0:
  * Removed various deprecated functionality.
  * Atomic files now only accept the `w` mode.
  * Change the usage part of help output for very long commands to
    wrap their arguments onto the next line, indented by 4 spaces.
  * Fix a bug where return code and error messages were incorrect when
    using ``CliRunner``.
  * added `get_current_context`.
  * added a `meta` dictionary to the context which is shared across
    the linked list of contexts to allow click utilities to place
    state there.
  * introduced `Context.scope`.
  * The `echo` function is now threadsafe: It calls the `write` method
    of the underlying object only once.
  * `prompt(hide_input=True)` now prints a newline on `^C`.
  * Click will now warn if users are using ``unicode_literals``.
  * Click will now ignore the ``PAGER`` environment variable if it is
    empty or contains only whitespace.
  * The `click-contrib` GitHub organization was created.
* Sat Jul 18 2015 arun@gmx.de
- update to version 4.1:
  * Fix a bug where error messages would include a trailing `None` string.
  * Fix a bug where Click would crash on docstrings with trailing newlines.
  * Support streams with encoding set to `None` on Python 3 by barfing with
    a better error.
  * Handle ^C in less-pager properly.
  * Handle return value of `None` from `sys.getfilesystemencoding`
  * Fix crash when writing to unicode files with `click.echo`.
  * Fix type inference with multiple options.
* Sat May  9 2015 arun@gmx.de
- update to version 4.0:
  * Added `color` parameters to lots of interfaces that directly or
    indirectly call into echoing.  This previously was always
    autodetection (with the exception of the `echo_via_pager`
    function).  Now you can forcefully enable or disable it,
    overriding the auto detection of Click.
  * Added an `UNPROCESSED` type which does not perform any type
    changes which simplifies text handling on 2.x / 3.x in some
    special advanced usecases.
  * Added `NoSuchOption` and `BadOptionUsage` exceptions for more
    generic handling of errors.
  * Added support for handling of unprocessed options which can be
    useful in situations where arguments are forwarded to underlying
    tools.
  * Added `max_content_width` parameter to the context which can be
    used to change the maximum width of help output.  By default Click
    will not format content for more than 80 characters width.
  * Added support for writing prompts to stderr.
  * Fix a bug when showing the default for multiple arguments.
  * Added support for custom subclasses to `option` and `argument`.
  * Fix bug in "clear()" on Windows when colorama is installed.
  * Reject "nargs=-1" for options properly.  Options cannot be
    variadic.
  * Fixed an issue with bash completion not working properly for
    commands with non ASCII characters or dashes.
  * Added a way to manually update the progressbar.
  * Changed the formatting of missing arguments.  Previously the
    internal argument name was shown in error messages, now the
    metavar is shown if passed.  In case an automated metavar is
    selected, it's stripped of extra formatting first.
- changes from version 3.3:
  * Fixed an issue with error reporting on Python 3 for invalid
    forwarding of commands.
* Sat May  2 2015 toms@opensuse.org
- Migrated to Python3
- Applied spec-cleaner
* Tue Aug 26 2014 p.drouand@gmail.com
- Fix %%description
* Tue Aug 26 2014 lowks@lowkster.com
- Initial package of python-click
